.. -*- coding: utf-8 -*-

.. _`adk-transitions-DIMS-dataset`:

AdK DIMS transitions ensemble dataset
=====================================

The macromolecular conformational transition between the closed
conformation of apo-adenylate kinase from E. coli (EcAdK) to the open
conformation was sampled with two methods: (1) dynamic importance
sampling molecular dynamics (DIMS MD) [Perilla2009]_, and (2)
Framework Rigidity Optimized Dynamics Algorithm (FRODA)
[Farrell2010]_. Each ensemble of independently generated paths
contains 200 trajectories in the CHARMM DCD format.

This data set contains the **DIMS** ensemble.

DIMS AdK (implicit solvent) with dynamic importance sampling MD from
closed (1AKE) to open (4AKE). CHARMM 22 force field. Topology file:
adk4ake.psf


Notes
-----

Data set characteristics:

 :size: 757 MB
 :number of trajectories:  200	
 :number of frames:  varies
 :number of atoms: 3341
 :creator: Sean L. Seyler
 :URL:  `https://doi.org/10.6084/m9.figshare.7165306.v2 <https://doi.org/10.6084/m9.figshare.7165306.v2>`_
 :license: `CC-BY 4.0 <https://creativecommons.org/licenses/by/4.0/legalcode>`_
 :reference: [Seyler2015]_
    

[Seyler2015] Seyler SL, Kumar A, Thorpe MF, Beckstein O (2015) Path
	     Similarity Analysis: A Method for Quantifying
	     Macromolecular Pathways. PLoS Comput Biol 11(10):
	     e1004568. https://doi.org/10.1371/journal.pcbi.1004568

